From: Dhruv Chawla <[email protected]>
Signed-off-by: Dhruv Chawla <[email protected]>
gcc/ChangeLog:
* sanopt.cc: Fix typos.
* sched-deps.cc (sched_analyze_2): Likewise.
* sel-sched-ir.cc (alloc_target_context): Likewise.
(av_set_union_and_live): Likewise.
(make_regions_from_loop_nest): Likewise.
* sel-sched-ir.h (struct _list_iterator): Likewise.
(struct succs_info): Likewise.
(SUCCS_ALL): Likewise.
* sel-sched.cc (moveup_expr): Likewise.
(moveup_expr_cached): Likewise.
(get_spec_check_type_for_insn): Likewise.
(get_expr_cost): Likewise.
(find_place_for_bookkeeping): Likewise.
(update_and_record_unavailable_insns): Likewise.
(move_op_at_first_insn): Likewise.
(calculate_new_fences): Likewise.
* shrink-wrap.cc (live_edge_for_reg): Likewise.
(try_shrink_wrapping): Likewise.
* simplify-rtx.cc (simplify_const_vector_subreg): Likewise.
* spellcheck.cc (assert_not_suggested_for): Likewise.
* stringpool.h: Likewise.
* sym-exec/sym-exec-state.cc (state::do_shift_right): Likewise.
(state::get_parent_with_const_child): Likewise.
(state::add_numbers): Likewise.
(state::add_equal_cond): Likewise.
(state::add_not_equal_cond): Likewise.
* sym-exec/sym-exec-state.h (class state): Likewise.
* symbol-summary.h: Likewise.
* symtab.cc (symtab_node::noninterposable_alias): Likewise.
(symtab_node::equal_address_to): Likewise.
* system.h (gcc_stablesort_r): Likewise.
* target-hooks-macros.h: Likewise.
* target.def: Likewise.
* targhooks.cc (default_floatn_mode): Likewise.
(default_floatn_builtin_p): Likewise.
(default_builtin_vector_alignment_reachable): Likewise.
(default_addr_space_for_artificial_rodata): Likewise.
* text-art/ruler.cc (x_ruler::update_layout): Likewise.
* text-art/ruler.h (class x_ruler): Likewise.
* timevar.def (TV_ISOLATE_ERRONEOUS_PATHS): Likewise.
* trans-mem.cc (ipa_tm_scan_irr_block): Likewise.
(ipa_tm_execute): Likewise.
* typed-splay-tree.h (class typed_splay_tree): Likewise.
* ubsan.cc (instrument_bool_enum_load): Likewise.
* value-prof.cc: Likewise.
* value-range.cc (irange::union_append): Likewise.
(irange::snap): Likewise.
(irange::snap_subranges): Likewise.
(irange::get_bitmask): Likewise.
* value-range.h (irange_bitmask::get_precision): Likewise.
* value-relation.cc (dom_oracle::next_relation): Likewise.
(block_relation_iterator::block_relation_iterator): Likewise.
* var-tracking.cc (shared_hash_find): Likewise.
(emit_note_insn_var_location): Likewise.
* varasm.cc (mergeable_constant_section): Likewise.
(finish_tm_clone_pairs): Likewise.
(default_binds_local_p_3): Likewise.
* vr-values.cc (simplify_using_ranges::simplify): Likewise.
* vtable-verify.cc: Likewise.
* warning-control.cc (has_warning_spec): Likewise.
* wide-int.cc (wi::from_mpz): Likewise.
(wi::force_to_size): Likewise.
(wi::divmod_internal): Likewise.
* wide-int.h (wi::bitreverse): Likewise.
(wi::umin): Likewise.
(wi::mul_high): Likewise.
(wi::div_trunc): Likewise.
(wi::sdiv_trunc): Likewise.
(wi::udiv_trunc): Likewise.
(wi::div_floor): Likewise.
(wi::sdiv_floor): Likewise.
(wi::udiv_floor): Likewise.
(wi::div_ceil): Likewise.
(wi::udiv_ceil): Likewise.
(wi::div_round): Likewise.
(wi::gcd): Likewise.
(wi::mod_trunc): Likewise.
(wi::smod_trunc): Likewise.
(wi::umod_trunc): Likewise.
(wi::mod_floor): Likewise.
(wi::umod_floor): Likewise.
(wi::mod_ceil): Likewise.
---
gcc/sanopt.cc | 2 +-
gcc/sched-deps.cc | 2 +-
gcc/sel-sched-ir.cc | 6 ++---
gcc/sel-sched-ir.h | 6 ++---
gcc/sel-sched.cc | 22 ++++++++---------
gcc/shrink-wrap.cc | 6 ++---
gcc/simplify-rtx.cc | 4 ++--
gcc/spellcheck.cc | 2 +-
gcc/stringpool.h | 2 +-
gcc/sym-exec/sym-exec-state.cc | 10 ++++----
gcc/sym-exec/sym-exec-state.h | 4 ++--
gcc/symbol-summary.h | 2 +-
gcc/symtab.cc | 4 ++--
gcc/system.h | 2 +-
gcc/target-hooks-macros.h | 4 ++--
gcc/target.def | 20 ++++++++--------
gcc/targhooks.cc | 8 +++----
gcc/text-art/ruler.cc | 2 +-
gcc/text-art/ruler.h | 2 +-
gcc/timevar.def | 2 +-
gcc/trans-mem.cc | 4 ++--
gcc/typed-splay-tree.h | 2 +-
gcc/ubsan.cc | 2 +-
gcc/value-prof.cc | 2 +-
gcc/value-range.cc | 10 ++++----
gcc/value-range.h | 2 +-
gcc/value-relation.cc | 8 +++----
gcc/var-tracking.cc | 4 ++--
gcc/varasm.cc | 6 ++---
gcc/vr-values.cc | 2 +-
gcc/vtable-verify.cc | 2 +-
gcc/warning-control.cc | 2 +-
gcc/wide-int.cc | 6 ++---
gcc/wide-int.h | 44 +++++++++++++++++-----------------
34 files changed, 104 insertions(+), 104 deletions(-)
diff --git a/gcc/sanopt.cc b/gcc/sanopt.cc
index 2f3eae7ed55..42c16d99f39 100644
--- a/gcc/sanopt.cc
+++ b/gcc/sanopt.cc
@@ -233,7 +233,7 @@ public:
/* Number of IFN_ASAN_CHECK statements. */
int asan_num_accesses;
- /* True when the current functions constains an ASAN_MARK. */
+ /* True when the current functions contains an ASAN_MARK. */
bool contains_asan_mark;
};
diff --git a/gcc/sched-deps.cc b/gcc/sched-deps.cc
index 1818a077bda..e72b53ccf79 100644
--- a/gcc/sched-deps.cc
+++ b/gcc/sched-deps.cc
@@ -2739,7 +2739,7 @@ sched_analyze_2 (class deps_desc *deps, rtx x, rtx_insn
*insn)
a jump insn which usually generates MOVE_BARRIER preventing
to move insns containing registers or memories through the
barrier. It is also wrong with generated code performance
- point of view as prefetch withouth dependecies will have a
+ point of view as prefetch without dependencies will have a
tendency to be issued later instead of earlier. It is hard
to generate accurate dependencies for prefetch insns as
prefetch has only the start address but it is better to have
diff --git a/gcc/sel-sched-ir.cc b/gcc/sel-sched-ir.cc
index 866b2d9875e..48651a81bba 100644
--- a/gcc/sel-sched-ir.cc
+++ b/gcc/sel-sched-ir.cc
@@ -344,7 +344,7 @@ alloc_target_context (void)
/* Init target context TC.
If CLEAN_P is true, then make TC as it is beginning of the scheduler.
- Overwise, copy current backend context to TC. */
+ Otherwise, copy current backend context to TC. */
static void
init_target_context (tc_t tc, bool clean_p)
{
@@ -2249,7 +2249,7 @@ av_set_union_and_live (av_set_t *top, av_set_t *fromp,
regset to_lv_set,
av_set_iterator i;
av_set_t *to_tailp, in_both_set = NULL;
- /* Delete from TOP all expres, that present in FROMP. */
+ /* Delete from TOP all exprs, that present in FROMP. */
FOR_EACH_EXPR_1 (expr1, i, top)
{
expr_t expr2 = av_set_lookup_and_remove (fromp, EXPR_VINSN (expr1));
@@ -6110,7 +6110,7 @@ make_regions_from_loop_nest (class loop *loop)
return true;
}
-/* Initalize data structures needed. */
+/* Initialize data structures needed. */
void
sel_init_pipelining (void)
{
diff --git a/gcc/sel-sched-ir.h b/gcc/sel-sched-ir.h
index 489b5460c48..b2894c95259 100644
--- a/gcc/sel-sched-ir.h
+++ b/gcc/sel-sched-ir.h
@@ -405,7 +405,7 @@ struct _list_iterator
/* The list we're iterating. */
_list_t *lp;
- /* True when this iterator supprts removing. */
+ /* True when this iterator supports removing. */
bool can_remove_p;
/* True when we've actually removed something. */
@@ -1008,7 +1008,7 @@ struct succ_iterator
/* A structure returning all successor's information. */
struct succs_info
{
- /* Flags that these succcessors were computed with. */
+ /* Flags that these successors were computed with. */
short flags;
/* Successors that correspond to the flags. */
@@ -1210,7 +1210,7 @@ get_all_loop_exits (basic_block bb)
/* Include all successors. */
#define SUCCS_ALL (SUCCS_NORMAL | SUCCS_BACK | SUCCS_OUT)
-/* We need to return a succ_iterator to avoid 'unitialized' warning
+/* We need to return a succ_iterator to avoid 'uninitialized' warning
during bootstrap. */
inline succ_iterator
_succ_iter_start (insn_t *succp, insn_t insn, int flags)
diff --git a/gcc/shrink-wrap.cc b/gcc/shrink-wrap.cc
index 1c5b8e5580f..175f7bcdce6 100644
--- a/gcc/shrink-wrap.cc
+++ b/gcc/shrink-wrap.cc
@@ -147,7 +147,7 @@ live_edge_for_reg (basic_block bb, int regno, int end_regno)
/* Try to move INSN from BB to a successor. Return true on success.
USES and DEFS are the set of registers that are used and defined
after INSN in BB. SPLIT_P indicates whether a live edge from BB
- is splitted or not. */
+ is split or not. */
static bool
move_insn_for_shrink_wrap (basic_block bb, rtx_insn *insn,
@@ -764,7 +764,7 @@ try_shrink_wrapping (edge *entry_edge, rtx_insn
*prologue_seq)
/* Now see if we can put the prologue at the start of PRO. Putting it
there might require duplicating a block that cannot be duplicated,
or in some cases we cannot insert the prologue there at all. If PRO
- wont't do, try again with the immediate dominator of PRO, and so on.
+ won't do, try again with the immediate dominator of PRO, and so on.
The blocks that need duplicating are those reachable from PRO but
not dominated by it. We keep in BB_WITH a bitmap of the blocks
@@ -994,7 +994,7 @@ try_shrink_wrapping (edge *entry_edge, rtx_insn
*prologue_seq)
handle_simple_exit (e);
/* Finally, we want a single edge to put the prologue on. Make a new
- block before the PRO block; the edge beteen them is the edge we want.
+ block before the PRO block; the edge between them is the edge we want.
Then redirect those edges into PRO that come from blocks without the
prologue, to point to the new block instead. The new prologue block
is put at the end of the insn chain. */
diff --git a/gcc/simplify-rtx.cc b/gcc/simplify-rtx.cc
index 392476754a0..39b6646874f 100644
--- a/gcc/simplify-rtx.cc
+++ b/gcc/simplify-rtx.cc
@@ -5117,7 +5117,7 @@ simplify_ashift:
(i386) extract scalar element from a vector using chain of
nested VEC_SELECT expressions. When input operand is a memory
operand, this operation can be simplified to a simple scalar
- load from an offseted memory address. */
+ load from an offsetted memory address. */
int n_elts;
if (GET_CODE (trueop0) == VEC_SELECT
&& (GET_MODE_NUNITS (GET_MODE (XEXP (trueop0, 0)))
@@ -8379,7 +8379,7 @@ simplify_const_vector_subreg (machine_mode outermode, rtx
x,
if (!native_encode_rtx (innermode, x, buffer, first_byte, buffer_bytes))
return NULL_RTX;
- /* Reencode the bytes as OUTERMODE. */
+ /* Re-encode the bytes as OUTERMODE. */
return native_decode_vector_rtx (outermode, buffer, 0, out_npatterns,
nelts_per_pattern);
}
diff --git a/gcc/spellcheck.cc b/gcc/spellcheck.cc
index 029bfb9a5e1..fb6489ecb39 100644
--- a/gcc/spellcheck.cc
+++ b/gcc/spellcheck.cc
@@ -354,7 +354,7 @@ assert_not_suggested_for (const location &loc, const char
*candidate,
assert_not_suggested_for (SELFTEST_LOCATION, CANDIDATE, TARGET); \
SELFTEST_END_STMT
-/* Verify that we offer varous suggestions that are meaningful,
+/* Verify that we offer various suggestions that are meaningful,
and that we don't offer various other ones that aren't (PR c/82967). */
static void
diff --git a/gcc/stringpool.h b/gcc/stringpool.h
index 9c6a9b68f2f..1e0f5101392 100644
--- a/gcc/stringpool.h
+++ b/gcc/stringpool.h
@@ -1,4 +1,4 @@
-/* Declarations and definitons for stringpool.cc.
+/* Declarations and definitions for stringpool.cc.
Copyright (C) 2013-2026 Free Software Foundation, Inc.
This file is part of GCC.
diff --git a/gcc/sym-exec/sym-exec-state.cc b/gcc/sym-exec/sym-exec-state.cc
index 1abc1f14128..81ff95918b9 100644
--- a/gcc/sym-exec/sym-exec-state.cc
+++ b/gcc/sym-exec/sym-exec-state.cc
@@ -767,7 +767,7 @@ state::do_shift_right (value *arg1, value *arg2, tree dest)
/* Adds two bits and carry value.
- Resturn result and stores new carry bit in "carry". */
+ Returns result and stores new carry bit in "carry". */
value_bit *
state::full_adder (value_bit *var1, value_bit *var2, value_bit **carry)
@@ -1161,7 +1161,7 @@ state::get_parent_with_const_child (value_bit *root,
bit_expression *&parent,
node_to_parent.put (expr_root, nullptr);
/* Traversing expression tree:
- considering only comutative expression nodes. */
+ considering only commutative expression nodes. */
while (!nodes_to_consider.is_empty ())
{
bit_expression *cur_element = *nodes_to_consider.begin ();
@@ -1239,7 +1239,7 @@ state::add_numbers (value *var1, const value *var2)
}
-/* ANDs every bit of the vector with var_bit, stroes the result in var1. */
+/* ANDs every bit of the vector with var_bit, stores the result in var1. */
void
state::and_number_bit (value *var1, value_bit *var_bit)
@@ -1325,7 +1325,7 @@ state::add_equal_cond (value *arg1, value *arg2)
}
/* When some of bits are constants and they differ by value,
- then we can evalate it to be false. */
+ then we can evaluate it to be false. */
for (size_t i = 0; i < arg1->length (); i++)
{
if (is_a<bit *> ((*arg1)[i]) && is_a<bit *> ((*arg2)[i])
@@ -1388,7 +1388,7 @@ state::add_not_equal_cond (value *arg1, value *arg2)
}
/* When some of bits are constants and they differ by value,
- then we can evalate it to be true. */
+ then we can evaluate it to be true. */
for (size_t i = 0; i < arg1->length (); i++)
{
if (is_a<bit *> ((*arg1)[i]) && is_a<bit *> ((*arg2)[i])
diff --git a/gcc/sym-exec/sym-exec-state.h b/gcc/sym-exec/sym-exec-state.h
index 1233999ba9a..01c92558067 100644
--- a/gcc/sym-exec/sym-exec-state.h
+++ b/gcc/sym-exec/sym-exec-state.h
@@ -183,7 +183,7 @@ class state {
/* Performs AND operation on two bits. */
static value_bit *and_two_bits (value_bit *arg1, value_bit *arg2);
- /* ANDs every bit of the value with var_bit, stroes the result in var1. */
+ /* ANDs every bit of the value with var_bit, stores the result in var1. */
void and_number_bit (value *var1, value_bit *var_bit);
/* Multiplies given values. The result is stored in dest. */
@@ -263,7 +263,7 @@ class state {
value *shift_left_by_const (const value *number, size_t shift_value);
/* Adds two bits and carry value.
- Resturn result and stores new carry bit in "carry". */
+ Returns result and stores new carry bit in "carry". */
static value_bit *full_adder (value_bit *var1, value_bit *var2,
value_bit **carry);
diff --git a/gcc/symbol-summary.h b/gcc/symbol-summary.h
index 998c0a7c712..01c2a481a7c 100644
--- a/gcc/symbol-summary.h
+++ b/gcc/symbol-summary.h
@@ -169,7 +169,7 @@ private:
related to a callgraph node. Typical usage can be seen in IPA passes which
create a temporary pass-related structures. The summary class registers
hooks that are triggered when a new node is inserted, duplicated and
deleted.
- A user of a summary class can ovewrite virtual methods than are triggered by
+ A user of a summary class can overwrite virtual methods than are triggered
by
the summary if such hook is triggered. Apart from a callgraph node, the
user
is given a data structure tied to the node.
diff --git a/gcc/symtab.cc b/gcc/symtab.cc
index c8c67c0ee15..28182f0c2c4 100644
--- a/gcc/symtab.cc
+++ b/gcc/symtab.cc
@@ -2048,7 +2048,7 @@ symtab_node::noninterposable_alias (symtab_node *node,
void *data)
return false;
}
-/* If node cannot be overwriten by static or dynamic linker to point to
+/* If node cannot be overwritten by static or dynamic linker to point to
different definition, return NODE. Otherwise look for alias with such
property and if none exists, introduce new one. */
@@ -2410,7 +2410,7 @@ symtab_node::equal_address_to (symtab_node *s2, bool
memory_accessed)
We probably should be consistent and use this fact here, too, but for
the moment return false only when we are called from the alias oracle.
Return 0 in C constant initializers and C++ manifestly constant
- expressions, the likelyhood that different vars will be aliases is
+ expressions, the likelihood that different vars will be aliases is
small and returning -1 lets us reject too many initializers. */
if (memory_accessed || folding_initializer)
return 0;
diff --git a/gcc/system.h b/gcc/system.h
index 01fa005509a..9b717080429 100644
--- a/gcc/system.h
+++ b/gcc/system.h
@@ -1229,7 +1229,7 @@ void gcc_stablesort_r (void *, size_t, size_t,
sort_r_cmp_fn *, void *data);
- the character 'k', if the number is higher than 10 K (in base 2)
but strictly lower than 10 M (in base 2)
- the character 'M' if the number is higher than 10 M (in base2)
- - the charcter ' ' if the number is strictly lower than 10 K */
+ - the character ' ' if the number is strictly lower than 10 K */
#define SIZE_LABEL(x) ((x) < 10 * ONE_K ? ' ' : ((x) < 10 * ONE_M ? 'k' : 'M'))
/* Display an integer amount as multiple of 1K or 1M (in base 2).
diff --git a/gcc/target-hooks-macros.h b/gcc/target-hooks-macros.h
index 163612f526c..2e48c749883 100644
--- a/gcc/target-hooks-macros.h
+++ b/gcc/target-hooks-macros.h
@@ -52,7 +52,7 @@
under the GPL, but not under the GFDL, put it in a comment above the hook
definition. If the function declaration is available both under GPL and
GFDL, but the documentation is only available under the GFDL, put the
- documentaton in tm.texi.in, heading with @hook <hookname> and closing
+ documentation in tm.texi.in, heading with @hook <hookname> and closing
the paragraph with @end deftypefn / deftypevr as appropriate, and marking
the next autogenerated hook with @hook <hookname>.
In both these cases, leave the DOC string empty, i.e. "".
@@ -68,7 +68,7 @@
A documentation string of "*" means not to emit any documentation at all,
and is mainly used internally for DEFHOOK_UNDOC. It should generally not
be used otherwise, but it has its use for exceptional cases where automatic
- documentation is not wanted, and the real documentation is elsewere, like
+ documentation is not wanted, and the real documentation is elsewhere, like
for TARGET_ASM_{,UN}ALIGNED_INT_OP, which are hooks only for implementation
purposes; they refer to structs, the components of which are documented as
separate hooks TARGET_ASM_{,UN}ALIGNED_[HSDT]I_OP.
diff --git a/gcc/target.def b/gcc/target.def
index cdb3a6a6c84..25a94559e19 100644
--- a/gcc/target.def
+++ b/gcc/target.def
@@ -1748,7 +1748,7 @@ DEFHOOK
(expand_var_decl,
"This hook, if defined, is used by accelerator target back-ends to expand\n\
specially handled kinds of @code{VAR_DECL} expressions. A particular use is\n\
-to place variables with specific attributes inside special accelarator\n\
+to place variables with specific attributes inside special accelerator\n\
memories. A return value of @code{NULL} indicates that the target does not\n\
handle this @code{VAR_DECL}, and normal RTL expanding is resumed.\n\
\n\
@@ -1970,7 +1970,7 @@ for a given element mode.\n\
\n\
The modes returned in @var{modes} should use the smallest element mode\n\
possible for the vectorization approach that they represent, preferring\n\
-integer modes over floating-poing modes in the event of a tie. The first\n\
+integer modes over floating-point modes in the event of a tie. The first\n\
mode should be the @code{TARGET_VECTORIZE_PREFERRED_SIMD_MODE} for its\n\
element mode.\n\
\n\
@@ -2822,11 +2822,11 @@ modes and they have different conditional execution
capability, such as ARM.",
DEFHOOK
(gen_ccmp_first,
"This function prepares to emit a comparison insn for the first compare in
a\n\
- sequence of conditional comparisions. It returns an appropriate comparison\n\
+ sequence of conditional comparisons. It returns an appropriate comparison\n\
with @code{CC} for passing to @code{gen_ccmp_next} or @code{cbranch_optab}.\n\
The insns to prepare the compare are saved in @var{prep_seq} and the
compare\n\
insns are saved in @var{gen_seq}. They will be emitted when all the\n\
- compares in the conditional comparision are generated without error.\n\
+ compares in the conditional comparison are generated without error.\n\
@var{code} is the @code{rtx_code} of the compare for @var{op0} and
@var{op1}.",
rtx, (rtx_insn **prep_seq, rtx_insn **gen_seq, rtx_code code, tree op0, tree
op1),
NULL)
@@ -2838,7 +2838,7 @@ DEFHOOK
@code{CC} for passing to @code{gen_ccmp_next} or @code{cbranch_optab}.\n\
The insns to prepare the compare are saved in @var{prep_seq} and the
compare\n\
insns are saved in @var{gen_seq}. They will be emitted when all the\n\
- compares in the conditional comparision are generated without error. The\n\
+ compares in the conditional comparison are generated without error. The\n\
@var{prev} expression is the result of a prior call to
@code{gen_ccmp_first}\n\
or @code{gen_ccmp_next}. It may return @code{NULL} if the combination of\n\
@var{prev} and this comparison is not supported, otherwise the result must\n\
@@ -3792,7 +3792,7 @@ DEFHOOK
built-in function without the @code{__builtin_} prefix in addition to the\n\
normal built-in function with the @code{__builtin_} prefix. The default is\n\
to only enable built-in functions without the @code{__builtin_} prefix for\n\
-the GNU C langauge. In strict ANSI/ISO mode, the built-in function without\n\
+the GNU C language. In strict ANSI/ISO mode, the built-in function without\n\
the @code{__builtin_} prefix is not enabled. The argument @code{FUNC} is
the\n\
@code{enum built_in_function} id of the function to be enabled.",
bool, (int func),
@@ -4061,7 +4061,7 @@ of spill registers and print a fatal error message.",
hook_bool_mode_false)
/* Register number for a flags register. Only needs to be defined if the
- target is constrainted to use post-reload comparison elimination. */
+ target is constrained to use post-reload comparison elimination. */
DEFHOOKPOD
(flags_regnum,
"If the target has a dedicated flags register, and it needs to use the\n\
@@ -4710,7 +4710,7 @@ DEFHOOK
compilation for the second case.\n\
\n\
For targets that have no processors that can execute instructions\n\
- speculatively an alternative implemenation of this hook is available:\n\
+ speculatively an alternative implementation of this hook is available:\n\
simply redefine this hook to @code{speculation_safe_value_not_needed}\n\
along with your other target hooks.",
bool, (bool active), default_have_speculation_safe_value)
@@ -4774,7 +4774,7 @@ hardware count register support for decrement and branch,
it may have to\n\
move IV value from hardware count register to general purpose register\n\
while doloop IV candidate is used for address IV uses. It probably takes\n\
expensive penalty. This hook allows target owners to define the cost for\n\
-this escpecially for address IV uses.\n\
+this especially for address IV uses.\n\
The default value is zero.",
int64_t, 0)
@@ -6579,7 +6579,7 @@ applied. @var{type} is either
@code{EXCESS_PRECISION_TYPE_IMPLICIT},\n\
@code{EXCESS_PRECISION_TYPE_STANDARD}, or\n\
@code{EXCESS_PRECISION_TYPE_FLOAT16}. For\n\
@code{EXCESS_PRECISION_TYPE_IMPLICIT}, the target should return which\n\
-precision and range operations will be implictly evaluated in regardless\n\
+precision and range operations will be implicitly evaluated in regardless\n\
of the excess precision explicitly added. For\n\
@code{EXCESS_PRECISION_TYPE_STANDARD}, \n\
@code{EXCESS_PRECISION_TYPE_FLOAT16}, and\n\
diff --git a/gcc/targhooks.cc b/gcc/targhooks.cc
index 295f70cb3f5..3b7d9f008e1 100644
--- a/gcc/targhooks.cc
+++ b/gcc/targhooks.cc
@@ -620,7 +620,7 @@ default_floatn_mode (int n, bool extended)
should implicitly enable the built-in function without the __builtin_ prefix
in addition to the normal built-in function with the __builtin_ prefix. The
default is to only enable built-in functions without the __builtin_ prefix
- for the GNU C langauge. The argument FUNC is the enum builtin_in_function
+ for the GNU C language. The argument FUNC is the enum builtin_in_function
id of the function to be enabled. */
bool
@@ -638,7 +638,7 @@ default_floatn_builtin_p (int func ATTRIBUTE_UNUSED)
return c_or_objective_c;
}
-/* Make some target macros useable by target-independent code. */
+/* Make some target macros usable by target-independent code. */
bool
targhook_words_big_endian (void)
{
@@ -1573,7 +1573,7 @@ default_builtin_vector_alignment_reachable (const_tree
/*type*/, bool is_packed)
}
/* By default, assume that a target supports any factor of misalignment
- memory access if it supports movmisalign patten.
+ memory access if it supports movmisalign pattern.
is_packed is true if the memory access is defined in a packed struct. */
bool
default_builtin_support_vector_misalignment (machine_mode mode,
@@ -1827,7 +1827,7 @@ default_addr_space_for_artificial_rodata (tree,
artificial_rodata)
}
-/* The defualt implementation of TARGET_HARD_REGNO_NREGS. */
+/* The default implementation of TARGET_HARD_REGNO_NREGS. */
unsigned int
default_hard_regno_nregs (unsigned int, machine_mode mode)
diff --git a/gcc/text-art/ruler.cc b/gcc/text-art/ruler.cc
index 1803db35a6c..f356b95c67c 100644
--- a/gcc/text-art/ruler.cc
+++ b/gcc/text-art/ruler.cc
@@ -346,7 +346,7 @@ x_ruler::update_layout ()
/* Now walk backwards trying to place them vertically,
setting m_text_rect.m_top_left.y for each label,
consolidating the rows where possible.
- The y cooordinates are stored with respect to label_dir::BELOW. */
+ The y coordinates are stored with respect to label_dir::BELOW. */
int label_y = 2;
for (int idx = m_labels.size () - 1; idx >= 0; idx--)
{
diff --git a/gcc/text-art/ruler.h b/gcc/text-art/ruler.h
index c0e99707db4..9012b92eac9 100644
--- a/gcc/text-art/ruler.h
+++ b/gcc/text-art/ruler.h
@@ -89,7 +89,7 @@ class x_ruler
# m_text_coord.x == 6
and m_text_coord is (2, 6).
- The y cooordinates are stored with respect to label_dir::BELOW;
+ The y coordinates are stored with respect to label_dir::BELOW;
for label_dir::ABOVE we flip them when painting the ruler. */
class label
{
diff --git a/gcc/timevar.def b/gcc/timevar.def
index 3824caa01bc..588d987ec35 100644
--- a/gcc/timevar.def
+++ b/gcc/timevar.def
@@ -175,7 +175,7 @@ DEFTIMEVAR (TV_TREE_OPS , "tree operand
scan")
DEFTIMEVAR (TV_TREE_SSA_DOMINATOR_OPTS , "dominator optimization")
DEFTIMEVAR (TV_TREE_SSA_THREAD_JUMPS , "backwards jump threading")
DEFTIMEVAR (TV_TREE_SRA , "tree SRA")
-DEFTIMEVAR (TV_ISOLATE_ERRONEOUS_PATHS , "isolate eroneous paths")
+DEFTIMEVAR (TV_ISOLATE_ERRONEOUS_PATHS , "isolate erroneous paths")
DEFTIMEVAR (TV_TREE_CCP , "tree CCP")
DEFTIMEVAR (TV_TREE_SPLIT_EDGES , "tree split crit edges")
DEFTIMEVAR (TV_TREE_REASSOC , "tree reassociation")
diff --git a/gcc/trans-mem.cc b/gcc/trans-mem.cc
index b10704b2f55..7b894eef3ae 100644
--- a/gcc/trans-mem.cc
+++ b/gcc/trans-mem.cc
@@ -4447,7 +4447,7 @@ ipa_tm_scan_irr_block (basic_block bb)
return false;
}
-/* For each of the blocks seeded witin PQUEUE, walk the CFG looking
+/* For each of the blocks seeded within PQUEUE, walk the CFG looking
for new irrevocable blocks, marking them in NEW_IRR. Don't bother
scanning past OLD_IRR or EXIT_BLOCKS. */
@@ -5516,7 +5516,7 @@ ipa_tm_execute (void)
/* Iterate scans until no more work to be done. Prefer not to use
vec::pop because the worklist tends to follow a breadth-first
- search of the callgraph, which should allow convergance with a
+ search of the callgraph, which should allow convergence with a
minimum number of scans. But we also don't want the worklist
array to grow without bound, so we shift the array up periodically. */
for (i = 0; i < irr_worklist.length (); ++i)
diff --git a/gcc/typed-splay-tree.h b/gcc/typed-splay-tree.h
index daf7a1dd184..f862f90b6ef 100644
--- a/gcc/typed-splay-tree.h
+++ b/gcc/typed-splay-tree.h
@@ -94,7 +94,7 @@ class typed_splay_tree
/* The root of the tree. */
splay_tree_node root;
- /* The comparision function. */
+ /* The comparison function. */
compare_fn comp;
/* The deallocate-key function. NULL if no cleanup is necessary. */
diff --git a/gcc/ubsan.cc b/gcc/ubsan.cc
index 6525d320fd4..55f3f7ec545 100644
--- a/gcc/ubsan.cc
+++ b/gcc/ubsan.cc
@@ -1856,7 +1856,7 @@ instrument_bool_enum_load (gimple_stmt_iterator *gsi)
}
/* Determine if we can propagate given LOCATION to ubsan_data descriptor to use
- new style handlers. Libubsan uses heuristics to destinguish between old and
+ new style handlers. Libubsan uses heuristics to distinguish between old and
new styles and relies on these properties for filename:
a) Location's filename must not be NULL.
diff --git a/gcc/value-prof.cc b/gcc/value-prof.cc
index 5c178a0d600..a7207bb8231 100644
--- a/gcc/value-prof.cc
+++ b/gcc/value-prof.cc
@@ -82,7 +82,7 @@ along with GCC; see the file COPYING3. If not see
compute_value_histograms() that translates the collected data to
histograms and attaches them to the profiled statements via
gimple_add_histogram_value(). Histograms are stored in a hash table
- that is attached to every intrumented function, see VALUE_HISTOGRAMS
+ that is attached to every instrumented function, see VALUE_HISTOGRAMS
in function.h.
The value-profile transformations driver is the function
diff --git a/gcc/value-range.cc b/gcc/value-range.cc
index a1e5c805057..fa17dd276af 100644
--- a/gcc/value-range.cc
+++ b/gcc/value-range.cc
@@ -1823,8 +1823,8 @@ irange::irange_single_pair_union (const irange &r)
bool
irange::union_append (const irange &r)
{
- // Check if the first range in R is an immmediate successor to the last
- // range, ths requiring a merge.
+ // Check if the first range in R is an immediate successor to the last
+ // range, thus requiring a merge.
signop sign = TYPE_SIGN (m_type);
wide_int lb = r.lower_bound ();
wide_int ub = upper_bound ();
@@ -2456,7 +2456,7 @@ irange::snap (const wide_int &lb, const wide_int &ub,
}
// This method loops through the subranges in THIS, and adjusts any bounds
-// to satisfy the contraints of the BITMASK. If a subrange is invalid,
+// to satisfy the constraints of the BITMASK. If a subrange is invalid,
// it is removed. TRUE is returned if there were any changes.
bool
@@ -2495,7 +2495,7 @@ irange::snap_subranges ()
}
// If the bitmask has a range representation, intersect this range with
-// the bitmasks range. Then ensure all enpoints match the bitmask.
+// the bitmasks range. Then ensure all endpoints match the bitmask.
// Return TRUE if the range changes at all.
bool
@@ -2565,7 +2565,7 @@ irange::get_bitmask () const
irange_bitmask bm (type (), lower_bound (), upper_bound ());
if (!m_bitmask.unknown_p ())
{
- // If the new intersection is unknown, it means there are inconstent
+ // If the new intersection is unknown, it means there are inconsistent
// bits, so simply return the original bitmask.
if (!bm.intersect (m_bitmask))
return m_bitmask;
diff --git a/gcc/value-range.h b/gcc/value-range.h
index 85deebab092..35421914a71 100644
--- a/gcc/value-range.h
+++ b/gcc/value-range.h
@@ -209,7 +209,7 @@ irange_bitmask::get_precision () const
return m_mask.get_precision ();
}
-// The following two functions are meant for backwards compatability
+// The following two functions are meant for backwards compatibility
// with the nonzero bitmask. A cleared bit means the value must be 0.
// A set bit means we have no information for the bit.
diff --git a/gcc/value-relation.cc b/gcc/value-relation.cc
index 2d397958719..932bb070dad 100644
--- a/gcc/value-relation.cc
+++ b/gcc/value-relation.cc
@@ -957,7 +957,7 @@ public:
};
// Given relation record PTR in block BB, return the next relation in the
-// list. If PTR is NULL, retreive the first relation in BB.
+// list. If PTR is NULL, retrieve the first relation in BB.
// If NAME is sprecified, return only relations which include NAME.
// Return NULL when there are no relations left.
@@ -966,7 +966,7 @@ dom_oracle::next_relation (basic_block bb, relation_chain
*ptr,
tree name) const
{
relation_chain *p;
- // No value_relation pointer is used to intialize the iterator.
+ // No value_relation pointer is used to initialize the iterator.
if (!ptr)
{
int bbi = bb->index;
@@ -985,7 +985,7 @@ dom_oracle::next_relation (basic_block bb, relation_chain
*ptr,
return p;
}
-// Instatiate a block relation iterator to iterate over the relations
+// Instantiate a block relation iterator to iterate over the relations
// on exit from block BB in ORACLE. Limit this to relations involving NAME
// if specified. Return the first such relation in VR if there is one.
@@ -1007,7 +1007,7 @@ block_relation_iterator::block_relation_iterator (const
relation_oracle *oracle,
m_done = true;
}
-// Retreive the next relation from the iterator and return it in VR.
+// Retrieve the next relation from the iterator and return it in VR.
void
block_relation_iterator::get_next_relation (value_relation &vr)
diff --git a/gcc/var-tracking.cc b/gcc/var-tracking.cc
index e7065e81ca5..c0c36d04388 100644
--- a/gcc/var-tracking.cc
+++ b/gcc/var-tracking.cc
@@ -1711,7 +1711,7 @@ shared_hash_find (shared_hash *vars, decl_or_value dv)
return shared_hash_find_1 (vars, dv, dv_htab_hash (dv));
}
-/* Return true if TVAL is better than CVAL as a canonival value. We
+/* Return true if TVAL is better than CVAL as a canonical value. We
choose lowest-numbered VALUEs, using the RTX address as a
tie-breaker. The idea is to arrange them into a star topology,
such that all of them are at most one step away from the canonical
@@ -8788,7 +8788,7 @@ emit_note_insn_var_location (variable **varp,
emit_note_data *data)
mode = GET_MODE (var->var_part[i].cur_loc);
if (mode == VOIDmode && var->onepart)
mode = DECL_MODE (decl);
- /* We ony track subparts of constant-sized objects, since at present
+ /* We only track subparts of constant-sized objects, since at present
there's no representation for polynomial pieces. */
if (!GET_MODE_SIZE (mode).is_constant (&size))
{
diff --git a/gcc/varasm.cc b/gcc/varasm.cc
index 5999f1e5420..c6daec8ec17 100644
--- a/gcc/varasm.cc
+++ b/gcc/varasm.cc
@@ -963,7 +963,7 @@ mergeable_constant_section (machine_mode mode,
unsigned HOST_WIDE_INT align,
unsigned int flags)
{
- /* If the mode is unknown (BLK or VOID), then return a non mergable section.
*/
+ /* If the mode is unknown (BLK or VOID), then return a non mergeable
section. */
if (mode == BLKmode || mode == VOIDmode)
return readonly_data_section;
unsigned HOST_WIDE_INT size;
@@ -6836,7 +6836,7 @@ finish_tm_clone_pairs (void)
if (tm_clone_hash == NULL)
return;
- /* We need a determenistic order for the .tm_clone_table, otherwise
+ /* We need a deterministic order for the .tm_clone_table, otherwise
we will get bootstrap comparison failures, so dump the hash table
to a vector, sort it, and dump the vector. */
@@ -7907,7 +7907,7 @@ default_binds_local_p_3 (const_tree exp, bool shlib, bool
weak_dominate,
/* Weakrefs may not bind locally, even though the weakref itself is always
static and therefore local. Similarly, the resolver for ifunc functions
might resolve to a non-local function.
- FIXME: We can resolve the weakref case more curefuly by looking at the
+ FIXME: We can resolve the weakref case more carefully by looking at the
weakref alias. */
if (lookup_attribute ("weakref", DECL_ATTRIBUTES (exp))
|| (!targetm.ifunc_ref_local_ok ()
diff --git a/gcc/vr-values.cc b/gcc/vr-values.cc
index 7d486c3a306..55a6fc6d87b 100644
--- a/gcc/vr-values.cc
+++ b/gcc/vr-values.cc
@@ -1812,7 +1812,7 @@ simplify_using_ranges::simplify (gimple_stmt_iterator
*gsi)
cmp_var = rhs1;
}
- /* If we could not find two-vals or the optimzation is invalid as
+ /* If we could not find two-vals or the optimization is invalid as
in divide by zero, new_rhs1 / new_rhs will be NULL_TREE. */
if (new_rhs1 && new_rhs2)
{
diff --git a/gcc/vtable-verify.cc b/gcc/vtable-verify.cc
index 52e46808f55..05e14b24788 100644
--- a/gcc/vtable-verify.cc
+++ b/gcc/vtable-verify.cc
@@ -86,7 +86,7 @@ along with GCC; see the file COPYING3. If not see
The vtable verification feature is controlled by the flag
'-fvtable-verify='. There are three flavors of this:
'-fvtable-verify=std', '-fvtable-verify=preinit', and
- '-fvtable-verify=none'. If the option '-fvtable-verfy=preinit' is
+ '-fvtable-verify=none'. If the option '-fvtable-verify=preinit' is
used, then our constructor initialization function gets put into the
preinit array. This is necessary if there are data sets that need
to be built very early in execution. If the constructor
diff --git a/gcc/warning-control.cc b/gcc/warning-control.cc
index fe1dd990d22..41f8a8c735c 100644
--- a/gcc/warning-control.cc
+++ b/gcc/warning-control.cc
@@ -265,7 +265,7 @@ bool has_warning_spec (const_tree t)
return !RESERVED_LOCATION_P (loc) && get_no_warning_bit (t);
}
-/* Retrieve warning dispostion bitmap for tree streaming. */
+/* Retrieve warning disposition bitmap for tree streaming. */
unsigned
get_warning_spec (const_tree t)
diff --git a/gcc/wide-int.cc b/gcc/wide-int.cc
index dbcd7cb0b8c..64d7ecfac9c 100644
--- a/gcc/wide-int.cc
+++ b/gcc/wide-int.cc
@@ -319,7 +319,7 @@ wi::from_mpz (const_tree type, mpz_t x, bool wrap)
/* Return the largest SGNed number that is representable in PRECISION bits.
- TODO: There is still code from the double_int era that trys to
+ TODO: There is still code from the double_int era that tries to
make up for the fact that double int's could not represent the
min and max values of all types. This code should be removed
because the min and max values can always be represented in
@@ -401,7 +401,7 @@ wi::force_to_size (HOST_WIDE_INT *val, const HOST_WIDE_INT
*xval,
}
/* This function hides the fact that we cannot rely on the bits beyond
- the precision. This issue comes up in the relational comparisions
+ the precision. This issue comes up in the relational comparisons
where we do allow comparisons of values of different precisions. */
static inline HOST_WIDE_INT
selt (const HOST_WIDE_INT *a, unsigned int len,
@@ -1865,7 +1865,7 @@ wi::divmod_internal (HOST_WIDE_INT *quotient, unsigned
int *remainder_len,
overflow = true;
/* Handle the overflow cases. Viewed as unsigned value, the quotient of
- (signed min / -1) has the same representation as the orignal dividend.
+ (signed min / -1) has the same representation as the original dividend.
We have traditionally made division by zero act as division by one,
so there too we use the original dividend. */
if (overflow)
diff --git a/gcc/wide-int.h b/gcc/wide-int.h
index e80e74cf9c7..f8d6af0fb48 100644
--- a/gcc/wide-int.h
+++ b/gcc/wide-int.h
@@ -36,7 +36,7 @@ along with GCC; see the file COPYING3. If not see
bits above the precision that has been specified. Because of
this, the default flavor has semantics that are simple to
understand and in general model the underlying hardware that the
- compiler is targetted for.
+ compiler is targeted for.
This flavor must be used at the RTL level of gcc because there
is, in general, not enough information in the RTL representation
@@ -119,7 +119,7 @@ along with GCC; see the file COPYING3. If not see
The offset_int and the widest_int flavors are more expensive
than the default wide int, so in addition to the caveats with these
- two, the default is the prefered representation.
+ two, the default is the preferred representation.
All three flavors of wide_int are represented as a vector of
HOST_WIDE_INTs. The default and widest_int vectors contain enough elements
@@ -2036,7 +2036,7 @@ wi::two (unsigned int precision)
namespace wi
{
- /* ints_for<T>::zero (X) returns a zero that, when asssigned to a T,
+ /* ints_for<T>::zero (X) returns a zero that, when assigned to a T,
gives that T the same precision as X. */
template<typename T, precision_type = int_traits<T>::precision_type>
struct ints_for
@@ -2684,7 +2684,7 @@ wi::bitreverse (const T &x)
return result;
}
-/* Return the mininum of X and Y, treating them both as having
+/* Return the minimum of X and Y, treating them both as having
signedness SGN. */
template <typename T1, typename T2>
inline WI_BINARY_RESULT (T1, T2)
@@ -2715,7 +2715,7 @@ wi::umin (const T1 &x, const T2 &y)
return wi::min (x, y, UNSIGNED);
}
-/* Return the maxinum of X and Y, treating them both as having
+/* Return the maximum of X and Y, treating them both as having
signedness SGN. */
template <typename T1, typename T2>
inline WI_BINARY_RESULT (T1, T2)
@@ -3116,7 +3116,7 @@ wi::mul_high (const T1 &x, const T2 &y, signop sgn)
return result;
}
-/* Return X / Y, rouding towards 0. Treat X and Y as having the
+/* Return X / Y, rounding towards 0. Treat X and Y as having the
signedness given by SGN. Indicate in *OVERFLOW if the result
overflows. */
template <typename T1, typename T2>
@@ -3141,7 +3141,7 @@ wi::div_trunc (const T1 &x, const T2 &y, signop sgn,
overflow_type *overflow)
return quotient;
}
-/* Return X / Y, rouding towards 0. Treat X and Y as signed values. */
+/* Return X / Y, rounding towards 0. Treat X and Y as signed values. */
template <typename T1, typename T2>
inline WI_BINARY_RESULT (T1, T2)
wi::sdiv_trunc (const T1 &x, const T2 &y)
@@ -3149,7 +3149,7 @@ wi::sdiv_trunc (const T1 &x, const T2 &y)
return div_trunc (x, y, SIGNED);
}
-/* Return X / Y, rouding towards 0. Treat X and Y as unsigned values. */
+/* Return X / Y, rounding towards 0. Treat X and Y as unsigned values. */
template <typename T1, typename T2>
inline WI_BINARY_RESULT (T1, T2)
wi::udiv_trunc (const T1 &x, const T2 &y)
@@ -3157,7 +3157,7 @@ wi::udiv_trunc (const T1 &x, const T2 &y)
return div_trunc (x, y, UNSIGNED);
}
-/* Return X / Y, rouding towards -inf. Treat X and Y as having the
+/* Return X / Y, rounding towards -inf. Treat X and Y as having the
signedness given by SGN. Indicate in *OVERFLOW if the result
overflows. */
template <typename T1, typename T2>
@@ -3192,7 +3192,7 @@ wi::div_floor (const T1 &x, const T2 &y, signop sgn,
overflow_type *overflow)
return quotient;
}
-/* Return X / Y, rouding towards -inf. Treat X and Y as signed values. */
+/* Return X / Y, rounding towards -inf. Treat X and Y as signed values. */
template <typename T1, typename T2>
inline WI_BINARY_RESULT (T1, T2)
wi::sdiv_floor (const T1 &x, const T2 &y)
@@ -3200,7 +3200,7 @@ wi::sdiv_floor (const T1 &x, const T2 &y)
return div_floor (x, y, SIGNED);
}
-/* Return X / Y, rouding towards -inf. Treat X and Y as unsigned values. */
+/* Return X / Y, rounding towards -inf. Treat X and Y as unsigned values. */
/* ??? Why do we have both this and udiv_trunc. Aren't they the same? */
template <typename T1, typename T2>
inline WI_BINARY_RESULT (T1, T2)
@@ -3209,7 +3209,7 @@ wi::udiv_floor (const T1 &x, const T2 &y)
return div_floor (x, y, UNSIGNED);
}
-/* Return X / Y, rouding towards +inf. Treat X and Y as having the
+/* Return X / Y, rounding towards +inf. Treat X and Y as having the
signedness given by SGN. Indicate in *OVERFLOW if the result
overflows. */
template <typename T1, typename T2>
@@ -3244,7 +3244,7 @@ wi::div_ceil (const T1 &x, const T2 &y, signop sgn,
overflow_type *overflow)
return quotient;
}
-/* Return X / Y, rouding towards +inf. Treat X and Y as unsigned values. */
+/* Return X / Y, rounding towards +inf. Treat X and Y as unsigned values. */
template <typename T1, typename T2>
inline WI_BINARY_RESULT (T1, T2)
wi::udiv_ceil (const T1 &x, const T2 &y)
@@ -3252,7 +3252,7 @@ wi::udiv_ceil (const T1 &x, const T2 &y)
return div_ceil (x, y, UNSIGNED);
}
-/* Return X / Y, rouding towards nearest with ties away from zero.
+/* Return X / Y, rounding towards nearest with ties away from zero.
Treat X and Y as having the signedness given by SGN. Indicate
in *OVERFLOW if the result overflows. */
template <typename T1, typename T2>
@@ -3305,7 +3305,7 @@ wi::div_round (const T1 &x, const T2 &y, signop sgn,
overflow_type *overflow)
return quotient;
}
-/* Return X / Y, rouding towards 0. Treat X and Y as having the
+/* Return X / Y, rounding towards 0. Treat X and Y as having the
signedness given by SGN. Store the remainder in *REMAINDER_PTR. */
template <typename T1, typename T2>
inline WI_BINARY_RESULT (T1, T2)
@@ -3360,7 +3360,7 @@ wi::gcd (const T1 &a, const T2 &b, signop sgn)
return y;
}
-/* Compute X / Y, rouding towards 0, and return the remainder.
+/* Compute X / Y, rounding towards 0, and return the remainder.
Treat X and Y as having the signedness given by SGN. Indicate
in *OVERFLOW if the division overflows. */
template <typename T1, typename T2>
@@ -3387,7 +3387,7 @@ wi::mod_trunc (const T1 &x, const T2 &y, signop sgn,
overflow_type *overflow)
return remainder;
}
-/* Compute X / Y, rouding towards 0, and return the remainder.
+/* Compute X / Y, rounding towards 0, and return the remainder.
Treat X and Y as signed values. */
template <typename T1, typename T2>
inline WI_BINARY_RESULT (T1, T2)
@@ -3396,7 +3396,7 @@ wi::smod_trunc (const T1 &x, const T2 &y)
return mod_trunc (x, y, SIGNED);
}
-/* Compute X / Y, rouding towards 0, and return the remainder.
+/* Compute X / Y, rounding towards 0, and return the remainder.
Treat X and Y as unsigned values. */
template <typename T1, typename T2>
inline WI_BINARY_RESULT (T1, T2)
@@ -3405,7 +3405,7 @@ wi::umod_trunc (const T1 &x, const T2 &y)
return mod_trunc (x, y, UNSIGNED);
}
-/* Compute X / Y, rouding towards -inf, and return the remainder.
+/* Compute X / Y, rounding towards -inf, and return the remainder.
Treat X and Y as having the signedness given by SGN. Indicate
in *OVERFLOW if the division overflows. */
template <typename T1, typename T2>
@@ -3441,7 +3441,7 @@ wi::mod_floor (const T1 &x, const T2 &y, signop sgn,
overflow_type *overflow)
return remainder;
}
-/* Compute X / Y, rouding towards -inf, and return the remainder.
+/* Compute X / Y, rounding towards -inf, and return the remainder.
Treat X and Y as unsigned values. */
/* ??? Why do we have both this and umod_trunc. Aren't they the same? */
template <typename T1, typename T2>
@@ -3451,7 +3451,7 @@ wi::umod_floor (const T1 &x, const T2 &y)
return mod_floor (x, y, UNSIGNED);
}
-/* Compute X / Y, rouding towards +inf, and return the remainder.
+/* Compute X / Y, rounding towards +inf, and return the remainder.
Treat X and Y as having the signedness given by SGN. Indicate
in *OVERFLOW if the division overflows. */
template <typename T1, typename T2>
@@ -3487,7 +3487,7 @@ wi::mod_ceil (const T1 &x, const T2 &y, signop sgn,
overflow_type *overflow)
return remainder;
}
-/* Compute X / Y, rouding towards nearest with ties away from zero,
+/* Compute X / Y, rounding towards nearest with ties away from zero,
and return the remainder. Treat X and Y as having the signedness
given by SGN. Indicate in *OVERFLOW if the division overflows. */
template <typename T1, typename T2>
diff --git a/gcc/sel-sched.cc b/gcc/sel-sched.cc
index ff937acdec1..ca68068fef0 100644
--- a/gcc/sel-sched.cc
+++ b/gcc/sel-sched.cc
@@ -71,7 +71,7 @@ along with GCC; see the file COPYING3. If not see
An expression is a vinsn with additional data characterizing its properties
at some point in the control flow graph. The data may be its usefulness,
- priority, speculative status, whether it was renamed/subsituted, etc.
+ priority, speculative status, whether it was renamed/substituted, etc.
An expression is described by expr_t type.
Availability set (av_set) is a set of expressions at a given control flow
@@ -525,7 +525,7 @@ static bitmap code_motion_visited_blocks = NULL;
/* The number of bookkeeping copies created. */
static int stat_bookkeeping_copies;
-/* The number of insns that required bookkeeiping for their scheduling. */
+/* The number of insns that required bookkeeping for their scheduling. */
static int stat_insns_needed_bookkeeping;
/* The number of insns that got renamed. */
@@ -2144,7 +2144,7 @@ moveup_expr (expr_t expr, insn_t through_insn, bool
inside_insn_group,
insn is pulled ahead of it. It's hard to figure out how to
introduce such a notion in sel-sched, but it already fails to
support debug insns in other ways, so we just go ahead and
- let the deug insns go corrupt for now. */
+ let the debug insns go corrupt for now. */
if (DEBUG_INSN_P (through_insn) && !DEBUG_INSN_P (insn))
return MOVEUP_EXPR_SAME;
@@ -2531,7 +2531,7 @@ moveup_expr_cached (expr_t expr, insn_t insn, bool
inside_insn_group)
basic blocks. */;
else if (try_bitmap_cache (expr, insn, inside_insn_group, &res))
/* When inside insn group, we do not want remove stores conflicting
- with previosly issued loads. */
+ with previously issued loads. */
got_answer = ! inside_insn_group || res != MOVEUP_EXPR_NULL;
else if (try_transformation_cache (expr, insn, &res))
got_answer = true;
@@ -3216,7 +3216,7 @@ get_spec_check_type_for_insn (insn_t insn, expr_t expr)
return to_check_ds;
}
/* Find the set of registers that are unavailable for storing expres
while moving ORIG_OPS up on the path starting from INSN due to
liveness (USED_REGS) or hardware restrictions (REG_RENAME_P).
@@ -3233,7 +3233,7 @@ get_spec_check_type_for_insn (insn_t insn, expr_t expr)
This function utilizes code_motion_path_driver (formerly find_used_regs_1)
to traverse the code motion paths. This helper function finds registers
- that are not available for storing expres while moving ORIG_OPS up on the
+ that are not available for storing exprs while moving ORIG_OPS up on the
path starting from INSN. A register considered as used on the moving path,
if one of the following conditions is not satisfied:
@@ -4303,7 +4303,7 @@ get_expr_cost (expr_t expr, fence_t fence)
{
if (!FENCE_STARTS_CYCLE_P (fence)
&& INSN_ASM_P (insn))
- /* This is asm insn which is tryed to be issued on the
+ /* This is asm insn which is tried to be issued on the
cycle not first. Issue it on the next cycle. */
return 1;
else
@@ -4715,7 +4715,7 @@ find_place_for_bookkeeping (edge e1, edge e2, fence_t
*fence_to_rewind)
return place_to_insert;
}
-/* Find a proper seqno for bookkeeing insn inserted at PLACE_TO_INSERT
+/* Find a proper seqno for bookkeeping insn inserted at PLACE_TO_INSERT
for JOIN_POINT. */
static int
find_seqno_for_bookkeeping (insn_t place_to_insert, insn_t join_point)
@@ -5673,7 +5673,7 @@ update_and_record_unavailable_insns (basic_block
book_block)
rtx_insn *bb_end = sel_bb_end (book_block);
/* First, get correct liveness in the bookkeeping block. The problem is
- the range between the bookeeping insn and the end of block. */
+ the range between the bookkeeping insn and the end of block. */
update_liveness_on_insn (bb_end);
if (control_flow_insn_p (bb_end))
update_liveness_on_insn (PREV_INSN (bb_end));
@@ -6107,7 +6107,7 @@ move_op_at_first_insn (insn_t insn, cmpd_local_params_p
lparams,
r1 := r2
Here, insn "r1 := r3" was scheduled at the current scheduling point
- and bookkeeping code was generated at the bookeeping block. This
+ and bookkeeping code was generated at the bookkeeping block. This
way insn "r1 := r2" is no longer available as a whole instruction
(but only as expr) ahead of insn "r1 := r3" in bookkeeping block.
This situation is handled by calling update_data_sets.
@@ -7431,7 +7431,7 @@ calculate_new_fences (flist_t fences, int orig_max_seqno,
int *ptime)
}
/* Update seqnos of insns given by PSCHEDULED_INSNS. MIN_SEQNO and MAX_SEQNO
- are the miminum and maximum seqnos of the group, HIGHEST_SEQNO_IN_USE is
+ are the minimum and maximum seqnos of the group, HIGHEST_SEQNO_IN_USE is
the highest seqno used in a region. Return the updated highest seqno. */
static int
update_seqnos_and_stage (int min_seqno, int max_seqno,
@@ -3216,7 +3216,7 @@ get_spec_check_type_for_insn (insn_t insn, expr_t expr)
return to_check_ds;
}
-/* Find the set of registers that are unavailable for storing expres
+/* Find the set of registers that are unavailable for storing exprs
while moving ORIG_OPS up on the path starting from INSN due to
liveness (USED_REGS) or hardware restrictions (REG_RENAME_P).
--
2.43.0